@@ -3,21 +3,20 @@ import requests
 from bs4 import BeautifulSoup
 import github3
 from packaging import version
-from datetime import datetime
+
 logging.basicConfig(level=logging.INFO)
 logger = logging.getLogger(__name__)
 
 VOID_URL = 'https://en.wikipedia.org/wiki/Void_(astronomy)'
-SHORT_DESCRIPTION_LEN = 50
 
 def is_dev_version(tag_name):
     return tag_name.endswith("-dev") or tag_name.endswith("-SNAPSHOT")
 
 
-def get_max_tag(tag, other_tag):
-    vers = version.parse(tag.name)
-    other_vers = version.parse(other_tag.name)
-    return tag if (vers > other_vers) else other_tag
+def get_max_tag(tag_name, other_tag_name ):
+    vers = version.parse(tag_name)
+    other_vers = version.parse(other_tag_name)
+    return tag_name if (vers > other_vers) else other_tag_name
 
 
 class CattleHead():
@@ -44,30 +43,20 @@ class CattleHead():
         self._changelog_url = f"http://{self._org}.github.io/{self._repo_name}/pdsen-corral/CHANGELOG.html"
         self._changelog_signets = self._get_changelog_signet()
         self._dev = dev
-
         self._version = self._get_latest_patch(minor=version)
-        self._version_name = self._version.name if self._version else None
-        if self._version:
-            update_date_iso = self._repo.commit(self._version.commit.sha).as_dict()['commit']['author']['date']
-            self._update = datetime.fromisoformat(update_date_iso.replace('Z', '+00:00'))
-        else:
-            self._update = None
-
-    def get_published_date(self):
-        return self._update
 
     def _get_latest_patch(self, minor=None):
 
         latest_tag = None
         for tag in self._repo.tags():
             if is_dev_version(tag.name) and self._dev:  # if we have a dev version and we look for dev version
-                latest_tag = get_max_tag(tag, latest_tag) if latest_tag else tag
+                latest_tag = get_max_tag(tag.name, latest_tag) if latest_tag else tag.name
             elif not (is_dev_version(tag.name) or self._dev):  # if we don't have a dev version and we look for stable version
                 if minor is None \
                         or (minor and (tag.name.startswith(minor) or tag.name.startswith(f'v{minor}'))):
-                    latest_tag = get_max_tag(tag, latest_tag) if latest_tag else tag
+                    latest_tag = get_max_tag(tag.name, latest_tag) if latest_tag else tag.name
 
-        return latest_tag if latest_tag else None
+        return latest_tag.__str__() if latest_tag else None
 
     def _get_cell(self, function):
         link_func = eval(f'self._get_{function}_link()')
@@ -77,12 +66,12 @@ class CattleHead():
         return f'{self._github_path}/releases/tag/{self._version}'
 
     def _get_manual_link(self):
-        if self._version_name:
-            url = f'https://{self._org}.github.io/{self._repo_name}/{self._version_name}'
+        if self._version:
+            url = f'https://{self._org}.github.io/{self._repo_name}/{self._version}'
             if requests.get(url).status_code != 404:
                 return url
-            elif self._version_name[0] == 'v':
-                url = f'https://{self._org}.github.io/{self._repo_name}/{self._version_name[1:]}'
+            elif self._version[0] == 'v':
+                url = f'https://{self._org}.github.io/{self._repo_name}/{self._version[1:]}'
                 if requests.get(url).status_code != 404:
                     return url
 
@@ -90,18 +79,18 @@ class CattleHead():
 
 
     def _get_changelog_link(self):
-        if self._version_name:
-            if self._version_name in self._changelog_signets:
-                return self._changelog_signets[self._version_name]
+        if self._version:
+            if self._version in self._changelog_signets:
+                return self._changelog_signets[self._version]
             else:
                 return None
         else:
             return "https://www.gnupg.org/gph/en/manual/r1943.html"
 
     def _get_requirements_link(self):
-        url = f'https://{self._org}.github.io/{self._repo_name}/pdsen-corral/{self._version_name}/REQUIREMENTS.html'
+        url = f'https://{self._org}.github.io/{self._repo_name}/pdsen-corral/{self._version}/REQUIREMENTS.html'
         logger.info(f'try url {url} for requirements')
-        if self._version_name and requests.get(url).status_code != 404:
+        if self._version and requests.get(url).status_code != 404:
             return url
         else:
             return None
@@ -115,13 +104,11 @@ class CattleHead():
     def get_table_row(self):
         icon_cells = [self._get_cell(k) for k in self._icon_dict.keys()]
 
-        description = self._description[:SHORT_DESCRIPTION_LEN]
-        description += f" [...]({self._github_path} 'more')" if len(self._description)>SHORT_DESCRIPTION_LEN else ''
+        more_description = f' [...]({self._github_path})' if len(self._description)>75 else ''
 
         return [self._name,
-                self._version_name if self._version_name else "None",
-                self._update.strftime('%y-%m-%d') if self._update else "Not yet",
-                description,
+                self._version if self._version else "None",
+                self._description[:75] + more_description,
                 *icon_cells
         ]
 
